//
// ********************************************************************
// *                                                                  *
// *       Primary Generator (source of beam)                         *
// *                                                                  *
// ********************************************************************
//
 
#include "myPrimaryGeneratorAction.hh"
#include "myDetectorConstruction.hh"
#include "Randomize.hh"
#include "G4Event.hh"
#include "G4ParticleGun.hh"
#include "G4ParticleTable.hh"
#include "G4ParticleDefinition.hh"
#include "globals.hh"
#include "TTree.h"
#include "outTree.h"
#include "TH1.h"
#include "TH2.h"
#include "TLorentzVector.h"
#include "G4SystemOfUnits.hh"

// ********************************************************************

myPrimaryGeneratorAction::myPrimaryGeneratorAction(myDetectorConstruction* det)
  :myDetector(det)
{
  G4String particle_name; 
  particle_name = "proton"; 
  G4int number_particle = 1;
  particleGun = new G4ParticleGun(number_particle);
  G4ParticleTable* particleTable = G4ParticleTable::GetParticleTable();
  G4ParticleDefinition* particle = particleTable->FindParticle(particle_name);
  particleGun->SetParticleDefinition(particle);


}

// ********************************************************************

myPrimaryGeneratorAction::~myPrimaryGeneratorAction()
{
  delete particleGun;
}

// ********************************************************************


void myPrimaryGeneratorAction::GeneratePrimaries(G4Event* anEvent)
{  

  G4double Ekin;

  G4ParticleTable* particleTable = G4ParticleTable::GetParticleTable();
  G4ParticleDefinition* particleE = particleTable->FindParticle("e-");
  G4ParticleDefinition* particlePro = particleTable->FindParticle("proton");
  G4ParticleDefinition* particlePhoton = particleTable->FindParticle("gamma");

  G4double detPlaneDistance = myDetector->GetCenterToDetector();
  double rotationAngleZ = myDetector->GetDetectorAngle()/deg; 
  G4double detPlaneX = detPlaneDistance*cos(rotationAngleZ*3.14159/180);
  G4double detPlaneY = detPlaneDistance*sin(rotationAngleZ*3.14159/180);
  G4double detPlaneZ = 0.0*cm;

  //Set the gun on y-z-plane.
  G4double xTmp = detPlaneDistance;
  G4double yTmp = myDetector->GetDetectorWidth()*(G4UniformRand()-0.5);
  G4double zTmp = myDetector->GetDetectorHeight()*(G4UniformRand()-0.5);
  //Make a vector of the gun position
  G4ThreeVector gunPositionVec(-xTmp,-yTmp,-zTmp);
  //Rotate the gun
  gunPositionVec.rotate(myDetector->GetDetectorAngle(),G4ThreeVector(0,0,1));
  
  double beamDirectionX = detPlaneX;
  double beamDirectionY = detPlaneY;
  double beamDirectionZ = detPlaneZ;
  

  G4double mElec = 0.511*MeV;
  G4double mPro = 0.938*GeV;
  //Ekin = sqrt(beamMomentum*beamMomentum + mPro*mPro) - mPro;//FOR PROTON
  //Ekin = sqrt(beamMomentum*beamMomentum + mElec*mElec) - mElec;//FOR ELECTRON

  Ekin = beamMomentum; //For photon

  beamEnergy = Ekin;

  //SHOOT particle
  particleGun->SetParticlePosition(gunPositionVec);
  //particleGun->SetParticleDefinition(particleE);//SET THE PARTICLE
  particleGun->SetParticleDefinition(particlePhoton);//SET THE PARTICLE
  particleGun->SetParticleEnergy(Ekin);
  particleGun->SetParticleMomentumDirection(G4ThreeVector(beamDirectionX,beamDirectionY,beamDirectionZ));
  particleGun->GeneratePrimaryVertex(anEvent);




}

// ********************************************************************

