//
// ********************************************************************
// *                                                                  *
// *    RunAction Class                                               *
// *                                                                  *
// *         Constructor and destructor run on creation and deletion  *
// *         BeginOfRunAction() called automaticly                    *
// *         EndofRunAction() called automaticly                      *
// *                                                                  *
// ********************************************************************
//

#include "myRunAction.hh"
#include "myRun.hh"
#include "G4ios.hh"

#include "G4RegionStore.hh"
#include "G4Region.hh"
#include "G4ProductionCuts.hh"
#include "G4UnitsTable.hh"
#include "Randomize.hh"


// ********************************************************************

myRunAction::myRunAction()
{;}

// ********************************************************************

myRunAction::~myRunAction()
{;}

// ********************************************************************
// ****   myRun GenerateRun Called (G4Run class)            ****
// ********************************************************************

G4Run* myRunAction::GenerateRun()
{ return new myRun; }

// ********************************************************************

void myRunAction::BeginOfRunAction(const G4Run* aRun)
{
  G4cout << "    Run:  " << aRun->GetRunID() << " started." << G4endl;
  G4cout << " "                                             << G4endl;
  G4Random::setTheSeed(seedVal);

}

// ********************************************************************
// ****   Print out summary of final measurements                  ****
// ********************************************************************

void myRunAction::EndOfRunAction(const G4Run* aRun)
{ 
  // Normalization factor is the surface area of detector sphere segments
  //   Area of spherical cap is 2*pie*radius*hieght_of_cap
  //   Hieght is radius(1-cos(theta))  theta=2.5 degrees
  G4double   sum = 0.0, Normalization_factor= 125.7337086; 
  G4String lineTitle;
  static   G4String blank = "                    ";
  static   G4String particleName[50] = { "Total_Particles", 
      "Ion", "He3", "aplha", "deuteron", "triton", 
      "gamma", "proton",
      "neutron", "electron", "positron", "muon_plus", "muon_minus", "tau_plus", "tau_minus", 
      "neutrinoE", "anti_neutrinoE", "neutrinoM", "anti_neutrinoM",
      "pion_plus", "pion_minus", "pion_zero", "pho_plus", "rho_minus", "rho_zero",
      "eta", "etaprime", "kaon_plus", "kaon_minus", "kaon_zero", "antikaon_zero", 
      "kaon_zero_long", "kaon_zero_short" };

  const myRun* theRun = (const myRun*)aRun;

  G4cout << "****************************************************************" << G4endl;
  G4cout << " Run Summary - Number of Events : " << theRun->GetNumberOfEvent() << G4endl;
  G4cout << "****************************************************************" << G4endl;
  G4cout << " "                                                                << G4endl;
  G4cout << "  Number of Particles Hitting Detector Region"                    << G4endl;
  G4cout << " "                                                                << G4endl;

  for(size_t i=0;i<33;i++)
    {
     lineTitle = "  Number of " + particleName[i] + blank.substr(particleName[i].length());
     sum=sum+((theRun->GetValue(i))*Normalization_factor);
     G4cout <<  lineTitle  << ((theRun->GetValue(i))*Normalization_factor) << G4endl;
     if(i==0){sum=0;}
     if(i==0){G4cout << " " << G4endl;}
    } 
  G4cout << " " << G4endl;
  G4cout << "  Sum of Listed Particles:      " << sum << G4endl;
  G4cout << " " << G4endl;
}

// ********************************************************************

